@@ -8,6 +8,11 @@ import pandas as pd
 
 
 def top_n(loop, n=10, gen=-1, key="value", ascending=False):
+    """return the top resylt of loop.
+    PendingDeprecation.
+
+    please use loop.top_n() directly.
+    """
     data = loop.data_all
     data = pd.DataFrame(data)
     if gen == -1:
