@@ -7,12 +7,13 @@
 from mgetool.tool import tt
 
 if __name__ == "__main__":
-    from sklearn.datasets import load_iris
+    from sklearn.datasets import load_iris,load_boston
     from bgp.skflow import SymbolLearning
     from sklearn import metrics
     from sklearn.utils import shuffle
 
-    data = load_iris()
+    # data = load_iris()
+    data = load_boston()
     x = data["data"]
     y = data["target"]
     c = [1, 2, 3]
@@ -23,18 +24,24 @@ if __name__ == "__main__":
 
     sl = SymbolLearning(loop="MultiMutateLoop", pop=500,
                         re_hall=3,
-                        gen=4, random_state=1,
-                        classification=True,
-                        scoring=[metrics.accuracy_score, ], score_pen=[1, ],
-                        store=True,
+                        gen=5, random_state=1,
+                        # classification=True,
+                        classification=False,
+                        # scoring=[metrics.accuracy_score, ], score_pen=[1, ],
+                        store=False,
+                        # store=True,
                         n_jobs=4,
-                        batch_size=5,
-                        batch_para = False
 
+                        batch_size=20,
+                        batch_para=False,
+
+                        # add_coef=False,
+                        # out_add =True,
+                        # vector_add=True,
                         )
     tt.t
     sl.fit(x, y, c=c,
-           #           x_group=[[1, 3], [0, 2], [4, 7]]
+                     # x_group=[[0, 1], [2, 3]]
            )
     tt.t
     tt.p
@@ -42,4 +49,4 @@ if __name__ == "__main__":
     # top_n = sl.loop.top_n(10)
     # print(sl.expr)
 
-    # top_n.to_csv(r"./re.csv")
\ No newline at end of file
+    # top_n.to_csv(r"./re.csv")
